@@ -37,21 +37,20 @@ sub theme_settings_raw
                        'settings_global_palette_unauthenticated',
                        'settings_cm_editor_palette',
                        'settings_theme_config_admins_only_privileged',
-                       'settings_embed_product_splash_privileged',
             ] }
         ],
 
         [
          {  'id'    => 's2',
-            'title' => &theme_text('settings_right_sysinfo_page_options'),
+            'title' => &theme_text('settings_right_content_options'),
             'data'  => [
-                       'settings_sysinfo_easypie_charts',
-                       'settings_sysinfo_easypie_charts_size',
-                       'settings_sysinfo_easypie_charts_width',
-                       'settings_sysinfo_easypie_charts_scale',
-                       'settings_sysinfo_hidden_panels_user',
-                       'settings_sysinfo_max_servers',
-                       'settings_sysinfo_real_time_status',
+                       'settings_roundish_content',
+                       'settings_content_margin_multiplier',
+                       'settings_right_table_force_single_column',
+                       'settings_right_table_links_type',
+                       'settings_right_table_links_sorted',
+                       'settings_right_table_animate_icons',
+                       'settings_right_table_grayscaled_icons',
             ] }
         ],
 
@@ -59,6 +58,7 @@ sub theme_settings_raw
          {  'id'    => 's3',
             'title' => &theme_text('settings_right_navigation_menu_options'),
             'data'  => [
+                       'settings_roundish_menu',
                        'settings_navigation_color',
                        'settings_grayscale_level_navigation',
                        'settings_sepia_level_navigation',
@@ -68,8 +68,6 @@ sub theme_settings_raw
                        'settings_brightness_level_navigation',
                        'settings_contrast_level_navigation',
                        'settings_navigation_always_collapse',
-                       'settings_leftmenu_width',
-                       'settings_auto_open_panels_on_proximity',
                        'settings_switch_rdisplay',
                        'settings_navigation_auto_fold_category',
                        'settings_leftmenu_section_hide_refresh_modules',
@@ -95,6 +93,7 @@ sub theme_settings_raw
          {  'id'    => 's4',
             'title' => &theme_text('settings_right_notification_slider_options'),
             'data'  => [
+                       'settings_roundish_slider',
                        'settings_side_slider_enabled',
                        'settings_side_slider_fixed',
                        'settings_side_slider_sysinfo_enabled',
@@ -105,13 +104,14 @@ sub theme_settings_raw
 
         [
          {  'id'    => 's5',
-            'title' => &theme_text('settings_right_table_options'),
+            'title' => &theme_text('settings_right_sysinfo_page_options'),
             'data'  => [
-                       'settings_right_table_links_type',
-                       'settings_right_table_links_sorted',
-                       'settings_right_table_animate_icons',
-                       'settings_right_table_grayscaled_icons',
-                       'settings_right_table_layout_control',
+                       'settings_sysinfo_easypie_charts',
+                       'settings_sysinfo_easypie_size',
+                       'settings_sysinfo_easypie_width',
+                       'settings_sysinfo_hidden_panels_user',
+                       'settings_sysinfo_real_time_status',
+                       'settings_sysinfo_max_servers',
             ] }
         ],
 
@@ -156,6 +156,7 @@ sub theme_settings_raw
                        'settings_hotkey_custom_9_user',
             ] }
         ]);
+
     # Add upgrade settings if available
     if ($theme_config{'settings_upgrade_allowed'} eq 'true') {
         push(@theme_settings_raw,
@@ -251,7 +252,7 @@ sub theme_settings_filter
         push(@theme_settings_filter, 'settings_show_terminal_link', 'settings_hotkey_shell');
     }
 
-    # Limit to certain options for non privleged user
+    # Limit to certain options for non privileged user
     if (!&webmin_user_is_admin()) {
         push(@theme_settings_filter,
              'settings_theme_config_admins_only_privileged',
@@ -259,9 +260,8 @@ sub theme_settings_filter
              'settings_hotkey_slider',
              'settings_global_palette_unauthenticated',
              'settings_sysinfo_easypie_charts',
-             'settings_sysinfo_easypie_charts_size',
-             'settings_sysinfo_easypie_charts_width',
-             'settings_sysinfo_easypie_charts_scale',
+             'settings_sysinfo_easypie_size',
+             'settings_sysinfo_easypie_width',
              'settings_sysinfo_max_servers',
              'settings_sysinfo_real_time_status',
              'settings_sysinfo_real_time_stored_duration',
@@ -316,6 +316,25 @@ sub theme_settings_format
     if ($v eq 'true' || $v eq 'false') {
         $v = ui_yesno_radio($k, $v, 'true', 'false');
 
+    } elsif ($k eq 'settings_content_margin_multiplier') {
+        my %val = (
+          '_side' => $theme_config{"${k}_side"},
+          '_top'  => $theme_config{"${k}_top"},
+        );
+        my $common = {
+          class => 'form-control ui_textbox', type  => 'range',
+          max   => 8, step  => 0.5,
+        };        
+        $v = join "\n", map {
+          ui_tag('input', undef, {
+            %$common,
+            name         => "${k}$_",
+            value        => $val{$_},
+            min          => ($_ eq '_side' ? 1 : 0.5),
+            'data-label' => $theme_text{"${k}$_"},
+          });
+        } qw(_side _top);
+
     } elsif ($k =~ /settings_sysinfo_hidden_panels_user/ &&
              $theme_config{'settings_sysinfo_hidden_panels_user'})
     {
@@ -337,8 +356,6 @@ sub theme_settings_format
                             \@excluded_accordions, scalar(@selected_excluded_accordions), 1);
         }
 
-    } elsif ($k eq 'settings_sysinfo_easypie_charts_size') {
-        $v = ui_textbox($k, $v, 3);
     } elsif ($k =~ /settings_hotkey_toggle_key_/ ||
              $k eq 'settings_hotkey_focus_search'  ||
              $k eq 'settings_hotkey_navigation'    ||
@@ -351,9 +368,7 @@ sub theme_settings_format
              $k eq 'settings_hotkey_favorites')
     {
         $v = ui_textbox($k, $v, 1, undef, 1);
-    } elsif ($k eq 'settings_sysinfo_easypie_charts_width' ||
-             $k eq 'settings_sysinfo_easypie_charts_scale' ||
-             $k eq 'settings_sysinfo_max_servers')
+    } elsif ($k eq 'settings_sysinfo_max_servers')
     {
         $v = ui_textbox($k, $v, 1);
     } elsif ($k eq 'settings_grayscale_level_navigation' ||
@@ -362,8 +377,7 @@ sub theme_settings_format
              $k eq 'settings_hue_level_navigation'        ||
              $k eq 'settings_invert_level_navigation'     ||
              $k eq 'settings_brightness_level_navigation' ||
-             $k eq 'settings_contrast_level_navigation'   ||
-             $k eq 'settings_leftmenu_width')
+             $k eq 'settings_contrast_level_navigation')
     {
 
         my $range_max = '1';
@@ -391,11 +405,6 @@ sub theme_settings_format
             $range_min  = '-360';
             $range_max  = '360';
             $range_step = '1';
-        } elsif ($k eq 'settings_leftmenu_width') {
-            $range_min  = '260';
-            $range_max  = '520';
-            $range_step = '1';
-            $iwidth     = '25';
         }
         $v = '
                 <input style="display: inline; width: ' .
@@ -573,6 +582,27 @@ sub theme_settings_format
         ]);
     } elsif ($k eq 'settings_document_title') {
         $v = settings_get_select_document_title($v, $k);
+    } elsif ($k eq 'settings_sysinfo_easypie_size') {
+        my $opts = [
+            [(146, $theme_text{'settings_sysinfo_easypie_size_smaller'})],
+            [(176, $theme_text{'settings_sysinfo_easypie_size_small'})],
+            [(186, $theme_text{'settings_sysinfo_easypie_size_medium'})],
+            [(0,   $theme_text{'settings_sysinfo_easypie_size_auto'})],
+            [(196, $theme_text{'settings_sysinfo_easypie_size_large'})],
+            [(206, $theme_text{'settings_sysinfo_easypie_size_extra_large'})]
+        ];
+        $v = &ui_select($k, $v, $opts);
+    } elsif ($k eq 'settings_sysinfo_easypie_width') {
+        my $common = {
+          class => 'form-control ui_textbox', type  => 'range',
+          max   => 7, step  => 1,
+        };        
+        $v = ui_tag('input', undef, {
+            %$common,
+            name         => $k,
+            value        => $v,
+            min          => 1,
+          });
     } elsif ($k eq 'settings_sysinfo_real_time_status') {
         my $realtime = 'settings_sysinfo_real_time_';
         my $realtime_pref = "${realtime}status_";
@@ -598,7 +628,6 @@ sub theme_settings_format
                       $v,
                       [[2, $theme_text{'settings_right_table_links_type_2'}],
                        [1, $theme_text{'settings_right_table_links_type_1'}],
-                       [0, $theme_text{'settings_right_table_links_type_0'}]
                       ]);
     }
     my $description = $theme_text{ $k . '_description' };
@@ -617,7 +646,7 @@ sub theme_settings_format
          (
           $description && (
               $k =~ /level_navigation|leftmenu_width/ ? undef :
-'<sup class="fa fa-fw fa-0_80x fa-question-circle module-help showpass-popover cursor-pointer tconfig-popover" data-html="true" data-toggle="popover" data-trigger="click" data-title="'
+'<sup class="fa fa-fw fa-question-circle module-help module-help-tconfig showpass-popover cursor-pointer tconfig-popover" data-html="true" data-toggle="popover" data-trigger="click" data-title="'
               . $theme_text{$k}
               . '" data-content="' . html_escape($description) . '"></sup>')
          ) .
@@ -807,7 +836,6 @@ sub settings_get_select_document_title
       <option value="6"'
       . ($v eq '6' && ' selected') . '>' . theme_text('settings_document_title_option_6', ucfirst($prod_name)) . '</option>
       </select>';
-
 }
 
 sub settings_get_select_default_module
