@@ -8,7 +8,8 @@ do 'cron-lib.pl';
 # For mode 0, returns 1 if installed, 0 if not
 sub is_installed
 {
-if (-d $config{'cron_dir'} || &has_command("crontab")) {
+if (-d $config{'cron_dir'} || &has_command("crontab") ||
+    -r $config{'single_file'}) {
 	return $_[0] ? 2 : 1;
 	}
 return 0;
