@@ -695,6 +695,19 @@ echo "  echo Force stopping Webmin server in $wadir" >>$config_dir/.stop-init
 echo "else" >>$config_dir/.stop-init
 echo "  echo Stopping Webmin server in $wadir" >>$config_dir/.stop-init
 echo "fi" >>$config_dir/.stop-init
+echo "targets=\"stats.pl shellserver.pl\"" >>$config_dir/.stop-init
+echo "collect_pids() {" >>$config_dir/.stop-init
+echo "  for s in \$targets; do" >>$config_dir/.stop-init
+echo "    ps axww | grep \"$wadir/\" | grep \"/\$s\" | grep -v grep" >>$config_dir/.stop-init
+echo "  done | awk '{print \$1}' | sort -u" >>$config_dir/.stop-init
+echo "}" >>$config_dir/.stop-init
+echo "pids=\$(collect_pids)" >>$config_dir/.stop-init
+echo "[ -n \"\$pids\" ] && kill \$pids 2>/dev/null || true" >>$config_dir/.stop-init
+echo "if [ \"\$1\" = \"--kill\" ]; then" >>$config_dir/.stop-init
+echo "  sleep 1" >>$config_dir/.stop-init
+echo "  pids=\$(collect_pids)" >>$config_dir/.stop-init
+echo "  [ -n \"\$pids\" ] && kill -KILL \$pids 2>/dev/null || true" >>$config_dir/.stop-init
+echo "fi" >>$config_dir/.stop-init
 echo "pidfile=\`grep \"^pidfile=\" $config_dir/miniserv.conf | sed -e 's/pidfile=//g'\`" >>$config_dir/.stop-init
 echo "pid=\`cat \$pidfile 2>/dev/null\`" >>$config_dir/.stop-init
 echo "if [ \"\$pid\" != \"\" ]; then" >>$config_dir/.stop-init
@@ -1063,7 +1076,7 @@ if [ "$nostart" = "" ]; then
 		echo "  - DateTime, DateTime::Locale, DateTime::TimeZone, Data::Dumper,"
 		echo "  - Digest::MD5, Digest::SHA, Encode::Detect, File::Basename,"
 		echo "  - File::Path, Net::SSLeay, Time::HiRes, Time::Local, Time::Piece,"
-		echo "  - JSON::XS, lib, open"
+		echo "  - Socket6, Sys::Syslog, JSON::XS, lib, open"
 		echo " Packages:"
 		echo "  - openssl - Cryptography library with TLS implementation"
 		echo "  - shared-mime-info - Shared MIME information database"
