@@ -258,13 +258,14 @@ foreach $serv (@services) {
 		$email .= $thisemail;
 		if ($config{'sched_single'} && $email) {
 			# Force the sending of one email and page per report
-			print DEBUG "  Sending email to ",
-				$config{'sched_email'},"\n";
+			my $e = $config{'sched_email'};
+			$e = $gconfig{'webmin_email_to'} if ($e eq '*');
+			print DEBUG "  Sending email to $e\n";
 			my $err = &send_status_email(
 				$email,
 				$config{'subject_mode'} ? $subj :
 				  &text('monitor_sub', $subj),
-				$config{'sched_email'});
+				$e);
 			print DEBUG $err ? "  Email failed : $err\n"
 					 : "  Done\n";
 			undef($email);
@@ -327,14 +328,15 @@ foreach $serv (@services) {
 
 # Send the email and page with all messages, if necessary
 if ($ecount && !$config{'sched_single'}) {
-	print DEBUG "Sending email to ",
-		$config{'sched_email'},"\n";
+	my $e = $config{'sched_email'};
+	$e = $gconfig{'webmin_email_to'} if ($e eq '*');
+	print DEBUG "Sending email to $e\n";
 	my $err = &send_status_email(
 		$email,
 		$config{'subject_mode'} ? $text{'monitor_sub2'} :
 		$ecount == 1 ? &text('monitor_sub', $subj) :
 			       &text('monitor_sub3', $ecount),
-		$config{'sched_email'});
+		$e);
 	print DEBUG $err ? "Email failed : $err\n" : "Done\n";
 	}
 if ($pager_msg && !$config{'sched_single'}) {
